package be.seeseemelk.llamascript.arguments;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * A bag of arguments that will keep the order in which the arguments were added.
 * The arguments are added with an index, which starts at one for the first argument.
 */
public class NamedArgumentBag implements ArgumentBag {
    private final Map<String, Object> values = new HashMap<>();

    /**
     * Adds an argument to the bag.
     * @param value The argument to add.
     * @return This instance.
     */
    public NamedArgumentBag set(String name, Object value) {
        values.put(name, value);
        return this;
    }

    @Override
    public void writeTo(StringBuilder builder) {
        for (var entry : values.entrySet()) {
            var string = Objects.toString(entry.getValue());
            builder.append(entry.getKey()).append(" -> ").append(string).append('\n');
        }
    }
}
